@@ -19,7 +19,7 @@ class Anilist:
         :param: activated: Bot Support - ensures that the program is activated. Default = True
         """
         self.access = {'header': {'Content-Type': 'application/json',
-                                    'User-Agent': 'Pymoe (github.com/ccubed/PyMoe)',
+                                    'User-Agent': 'AnilistPython (github.com/ReZeroE/AnilistPython)',
                                     'Accept': 'application/json'},
                          'authurl': 'https://anilist.co/api',
                          'apiurl': 'https://graphql.anilist.co',
@@ -50,18 +50,21 @@ class Anilist:
             max_result = i + 1
             counter += 1
         
-            if counter != 1: # only one result found if counter == 1
-                try:
-                    user_input = int(input("Please select the anime that you are searching for in number: "))
-                except TypeError:
-                    print(f"Your input is incorrect! Please try again!")
-                    return -1
+        if counter > 1: # only one result found if counter == 1
+            try:
+                user_input = int(input("Please select the anime that you are searching for in number: "))
+            except TypeError:
+                print(f"Your input is incorrect! Please try again!")
+                return -1
 
-                if user_input > max_result or user_input <= 0:
-                    print("Your input does not correspound to any of the anime displayed!")
-                    return -1
-            else:
-                user_input = 1
+            if user_input > max_result or user_input <= 0:
+                print("Your input does not correspound to any of the anime displayed!")
+                return -1
+        elif counter == 0:
+            print(f'No search result has been found for the anime "{anime_name}"!')
+            return -1
+        else:
+            user_input = 1
 
         return data['data']['Page']['media'][user_input - 1]['id']
 
@@ -178,7 +181,7 @@ class Anilist:
                 print(f'{counter + 1}. {last_name}, {first_name}')
             counter += 1
 
-        if counter != 1: # only one result found if counter == 1
+        if counter > 1: # only one result found if counter == 1
             try:
                 user_input = int(input("Please select the character that you are searching for in number: "))
             except TypeError:
@@ -188,6 +191,9 @@ class Anilist:
             if user_input > max_result or user_input <= 0:
                 print("Your input does not correspound to any of the characters!")
                 return -1
+        elif counter == 0:
+            print(f'No search result has been found for the character "{character_name}"!')
+            return -1
         else:
             user_input = 1
 
